/* This file is part of Libspectre.
 * 
 * Copyright (C) 2007 Albert Astals Cid <aacid@kde.org>
 * Copyright (C) 2007 Carlos Garcia Campos <carlosgc@gnome.org>
 *
 * Libspectre is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * Libspectre is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef SPECTRE_MACROS_H
#define SPECTRE_MACROS_H

#ifdef  __cplusplus
#  define SPECTRE_BEGIN_DECLS  extern "C" {
#  define SPECTRE_END_DECLS    }
#else
#  define SPECTRE_BEGIN_DECLS
#  define SPECTRE_END_DECLS
#endif

#ifndef TRUE
#  define TRUE 1
#endif
#ifndef FALSE
#  define FALSE 0
#endif

#ifndef NULL
#  ifdef __cplusplus
#    define NULL        (0L)
#  else /* !__cplusplus */
#    define NULL        ((void*) 0)
#  endif /* !__cplusplus */
#endif

#if defined(_WIN32)
#  define SPECTRE_PUBLIC __declspec(dllexport)
#elif defined(__GNUC__)
#  define SPECTRE_PUBLIC __attribute__((visibility("default"))) extern
#else
#  define SPECTRE_PUBLIC
#endif

#endif /* SPECTRE_MACROS_H */
